@@ -26,8 +26,8 @@ IntervalConstrict <- function(Simb = Simb, SubVar = SubVar, qi = qi, QI = QI, sp
             message("Warning infinite values calculated for your quantity of interest. Consider changing the difference between Xj and Xl.")
         }
     }
-    if (any(Simb$QI > 500) & isTRUE(spin)){
-    	message("Warning very large quantity of interest values. SPIn may not be found. Try spin = FALSE.")
+    if (any(Simb$QI > 800) & isTRUE(spin)){
+    	message("Warning large quantity of interest values estimated. SPIn may not be found. If so, try spin = FALSE.")
     }
 
 	Lower <- Upper <- NULL
